@@ -1,10 +1,11 @@
 package bignum;
 require 5.005;
 
-$VERSION = '0.10';
+$VERSION = '0.12';
 use Exporter;
-@ISA =       qw( Exporter );
-@EXPORT_OK = qw( ); 
+@EXPORT_OK 	= qw( ); 
+@EXPORT 	= qw( inf NaN ); 
+@ISA 		= qw( Exporter );
 
 use strict;
 
@@ -123,7 +124,6 @@ sub import
     {
     require Math::BigInt::Trace; $class = 'Math::BigInt::Trace';
     $upgrade = 'Math::BigFloat::Trace';	
-    print STDERR "Loading $class";
     }
   else
     {
@@ -148,7 +148,6 @@ sub import
     {
     require Math::BigFloat::Trace; $class = 'Math::BigFloat::Trace';
     $downgrade = 'Math::BigInt::Trace';	
-    print STDERR "Loading $class";
     }
   else
     {
@@ -168,8 +167,12 @@ sub import
     print "Math::BigFloat\t\t v$Math::BigFloat::VERSION\n";
     exit;
     }
+  $self->export_to_level(1,$self,@a);		# export inf and NaN
   }
 
+sub inf () { Math::BigInt->binf(); }
+sub NaN () { Math::BigInt->bnan(); }
+
 1;
 
 __END__
@@ -183,7 +186,9 @@ bignum - Transparent BigNumber support for Perl
   use bignum;
 
   $x = 2 + 4.5,"\n";			# BigFloat 6.5
-  print 2 ** 512 * 0.1;			# really is what you think it is
+  print 2 ** 512 * 0.1,"\n";		# really is what you think it is
+  print inf * inf,"\n";			# prints inf
+  print NaN * 3,"\n";			# prints NaN
 
 =head1 DESCRIPTION
 
@@ -235,6 +240,29 @@ This prints out the name and version of all modules used and then exits.
 
 	perl -Mbignum=v -e ''
 
+=head2 METHODS
+
+Beside import() and AUTOLOAD() there are only a few other methods.
+
+=over 2
+
+=item inf()
+
+A shortcut to return Math::BigInt->binf(). Usefull because Perl does not always
+handle bareword C<inf> properly.
+
+=item NaN()
+
+A shortcut to return Math::BigInt->bnan(). Usefull because Perl does not always
+handle bareword C<NaN> properly.
+
+=item upgrade()
+
+Return the class that numbers are upgraded to, is in fact returning
+C<$Math::BigInt::upgrade>.
+
+=back
+
 =head2 MATH LIBRARY
 
 Math with the numbers is done (by default) by a module called
