@@ -1,10 +1,11 @@
 package bigrat;
 require 5.005;
 
-$VERSION = '0.04';
+$VERSION = '0.05';
 use Exporter;
-@ISA =       qw( Exporter );
-@EXPORT_OK = qw( ); 
+@ISA		= qw( Exporter );
+@EXPORT_OK	= qw( ); 
+@EXPORT		= qw( inf NaN ); 
 
 use strict;
 
@@ -141,8 +142,12 @@ sub import
     print "Math::BigRat\t\t v$Math::BigRat::VERSION\n";
     exit;
     }
+  $self->export_to_level(1,$self,@a);           # export inf and NaN
   }
 
+sub inf () { Math::BigInt->binf(); }
+sub NaN () { Math::BigInt->bnan(); }
+
 1;
 
 __END__
